==> bs_python_utils-0.6.1.tar.gz: bs_python_utils-0.6.1/README.md <==
# bs-python-utils

![GitHub last commit](https://img.shields.io/github/last-commit/bsalanie/bs-python-utils)

<!-- [![Release](https://img.shields.io/github/v/release/bsalanie/bs-python-utils)](https://img.shields.io/github/v/release/bsalanie/bs-python-utils) -->

[![Build status](https://img.shields.io/github/actions/workflow/status/bsalanie/bs-python-utils/main.yml?branch=main)](https://github.com/bsalanie/bs-python-utils/actions/workflows/main.yml?query=branch%3Amain) <!-- [![codecov](https://codecov.io/gh/bsalanie/bs-python-utils/branch/main/graph/badge.svg)](https://codecov.io/gh/bsalanie/bs-python-utils) --> <!-- [![Commit activity](https://img.shields.io/github/commit-activity/m/bsalanie/bs-python-utils)](https://img.shields.io/github/commit-activity/m/bsalanie/bs-python-utils) --> [![License](https://img.shields.io/github/license/bsalanie/bs-python-utils)](https://img.shields.io/github/license/bsalanie/bs-python-utils)

My Python utilities.

- **Github repository**: <https://github.com/bsalanie/bs-python-utils/>
- **Documentation** <https://bsalanie.github.io/bs-python-utils/>

### Release notes

#### 0.6.1 (November 18, 2023)
Added a Matplotlib plot for discrete choice models, and a density plot for Seaborn.

#### 0.6 (November 9, 2023)

Added matrix heatmap plot in Altair and Streamlit utility code.

#### 0.5.5 (October 23, 2023)

Added `fstring***` in `bsutils`.

#### 0.5.2 (August 16, 2023)

Added two interpolation routines from values at the Chebyshev nodes in `chebyshev` module.

#### 0.5.1 (August 14, 2023)

Added two functions to draw random samples in `bsstats` module.

#### 0.5 (August 7, 2023)

Added 1-dimensional root finding in `chebyshev` module.

#### 0.4.2 (August 2, 2023)

Updated the docs.

#### 0.4.1 (July 23, 2023)

Only print if verbose in bivariate quantiles.

#### 0.4 (July 22, 2023)

Added bivariate quantiles and ranks à la optimal transportation.

#### 0.3 (July 21, 2023)

Added in Numpy utils a function to set upper and lower triangle to a scalar;
and `minimize_free` in `bs_opt`.

#### 0.2 (July 17, 2023)

Fixed printing in accelerated gradient descent.

#### 0.1 (June 20, 2023)

Added `grid_function` and the `chebyshev` module.

#### 0.0.6 (May 9, 2023)

Improved docs.

#### 0.0.5 (May 8, 2023)

Added `final_s` in `bsutils`.

#### 0.0.4 (May 2, 2023)

Added Legendre polynomials and quantile routines in `bsnputils`.

#### 0.0.3 (April 24, 2023)

Satisfied mypy.

#### 0.0.2 (April 24, 2023)

Fixed main PyPI page.

==> bs_python_utils-0.6.2.tar.gz: bs_python_utils-0.6.2/README.md <==
# bs-python-utils

![GitHub last commit](https://img.shields.io/github/last-commit/bsalanie/bs-python-utils)

<!-- [![Release](https://img.shields.io/github/v/release/bsalanie/bs-python-utils)](https://img.shields.io/github/v/release/bsalanie/bs-python-utils) -->

[![Build status](https://img.shields.io/github/actions/workflow/status/bsalanie/bs-python-utils/main.yml?branch=main)](https://github.com/bsalanie/bs-python-utils/actions/workflows/main.yml?query=branch%3Amain) <!-- [![codecov](https://codecov.io/gh/bsalanie/bs-python-utils/branch/main/graph/badge.svg)](https://codecov.io/gh/bsalanie/bs-python-utils) --> <!-- [![Commit activity](https://img.shields.io/github/commit-activity/m/bsalanie/bs-python-utils)](https://img.shields.io/github/commit-activity/m/bsalanie/bs-python-utils) --> [![License](https://img.shields.io/github/license/bsalanie/bs-python-utils)](https://img.shields.io/github/license/bsalanie/bs-python-utils)

My Python utilities.

- **Github repository**: <https://github.com/bsalanie/bs-python-utils/>
- **Documentation** <https://bsalanie.github.io/bs-python-utils/>

### Release notes

#### 0.6.1 and 0.6.2 (November 18, 2023)
Added a Matplotlib plot for discrete choice models, a boxplot for Altair, and a density plot for Seaborn.

#### 0.6 (November 9, 2023)

Added matrix heatmap plot in Altair and Streamlit utility code.

#### 0.5.5 (October 23, 2023)

Added `fstring***` in `bsutils`.

#### 0.5.2 (August 16, 2023)

Added two interpolation routines from values at the Chebyshev nodes in `chebyshev` module.

#### 0.5.1 (August 14, 2023)

Added two functions to draw random samples in `bsstats` module.

#### 0.5 (August 7, 2023)

Added 1-dimensional root finding in `chebyshev` module.

#### 0.4.2 (August 2, 2023)

Updated the docs.

#### 0.4.1 (July 23, 2023)

Only print if verbose in bivariate quantiles.

#### 0.4 (July 22, 2023)

Added bivariate quantiles and ranks à la optimal transportation.

#### 0.3 (July 21, 2023)

Added in Numpy utils a function to set upper and lower triangle to a scalar;
and `minimize_free` in `bs_opt`.

#### 0.2 (July 17, 2023)

Fixed printing in accelerated gradient descent.

#### 0.1 (June 20, 2023)

Added `grid_function` and the `chebyshev` module.

#### 0.0.6 (May 9, 2023)

Improved docs.

#### 0.0.5 (May 8, 2023)

Added `final_s` in `bsutils`.

#### 0.0.4 (May 2, 2023)

Added Legendre polynomials and quantile routines in `bsnputils`.

#### 0.0.3 (April 24, 2023)

Satisfied mypy.

#### 0.0.2 (April 24, 2023)

Fixed main PyPI page.
